pub async fn initialize_and_merge_configurations(
environment: &MountainEnvironment,
) -> Result<(), CommonError>Expand description
Logic to load and merge all configuration files into the effective
configuration stored in ApplicationState.
pub async fn initialize_and_merge_configurations(
environment: &MountainEnvironment,
) -> Result<(), CommonError>Logic to load and merge all configuration files into the effective
configuration stored in ApplicationState.