pub(super) async fn read_and_parse_configuration_file(
environment: &MountainEnvironment,
path: &Option<PathBuf>,
) -> Result<Value, CommonError>Expand description
An internal helper to read and parse a single JSON configuration file.
pub(super) async fn read_and_parse_configuration_file(
environment: &MountainEnvironment,
path: &Option<PathBuf>,
) -> Result<Value, CommonError>An internal helper to read and parse a single JSON configuration file.